<!DOCTYPE html>
<html>
<style>
table, th, td {
  border:1px solid black;
}
</style>
<body><h1>{{valid_check}}</h1><h2>Percent Designs Pass</h2><table style="width:90%">
  <tr><th></th>
<th>bright_time</th>
<th>dark_faint</th>
<th>dark_monit</th>
<th>dark_plane</th>
<th>dark_rm</th>
</tr>
<tr>
<td>APO {{valid_check}}</td>
<td>{{APO_bright_time}}</td>
<td>{{APO_dark_faint}}</td>
<td>{{APO_dark_monit}}</td>
<td>{{APO_dark_plane}}</td>
<td>{{APO_dark_rm}}</td>
</tr>
<tr>
<td>LCO {{valid_check}}</td>
<td>{{LCO_bright_time}}</td>
<td>{{LCO_dark_faint}}</td>
<td>{{LCO_dark_monit}}</td>
<td>{{LCO_dark_plane}}</td>
<td>{{LCO_dark_rm}}</td>
</tr>
</table>
<h3>{{valid_check}} (bright_time)</h3>
<img src="../dist_plots/{{valid_check}}_bright_time.png" width="80%">
<h3>{{valid_check}} (dark_faint)</h3>
<img src="../dist_plots/{{valid_check}}_dark_faint.png" width="80%">
<h3>{{valid_check}} (dark_monit)</h3>
<img src="../dist_plots/{{valid_check}}_dark_monit.png" width="80%">
<h3>{{valid_check}} (dark_plane)</h3>
<img src="../dist_plots/{{valid_check}}_dark_plane.png" width="80%">
<h3>{{valid_check}} (dark_rm)</h3>
<img src="../dist_plots/{{valid_check}}_dark_rm.png" width="80%">
</body>
</html>